"""
    EMIL AccountingService

    The EMIL AccountingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.accounting
from eis.accounting.model.booking_entry_class import BookingEntryClass
globals()['BookingEntryClass'] = BookingEntryClass
from eis.accounting.model.create_booking_entry_response_class import CreateBookingEntryResponseClass


class TestCreateBookingEntryResponseClass(unittest.TestCase):
    """CreateBookingEntryResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testCreateBookingEntryResponseClass(self):
        """Test CreateBookingEntryResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = CreateBookingEntryResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
