"""
    EMIL AccountingService

    The EMIL AccountingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.accounting
from eis.accounting.model.booking_entry_class import BookingEntryClass
globals()['BookingEntryClass'] = BookingEntryClass
from eis.accounting.model.list_booking_entries_response_class import ListBookingEntriesResponseClass


class TestListBookingEntriesResponseClass(unittest.TestCase):
    """ListBookingEntriesResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListBookingEntriesResponseClass(self):
        """Test ListBookingEntriesResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListBookingEntriesResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
