"""
    EMIL AccountingService

    The EMIL AccountingService API description  # noqa: E501

    The version of the OpenAPI document: 1.0
    Contact: kontakt@emil.de
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import eis.accounting
from eis.accounting.model.personal_account_class import PersonalAccountClass
globals()['PersonalAccountClass'] = PersonalAccountClass
from eis.accounting.model.list_personal_accounts_response_class import ListPersonalAccountsResponseClass


class TestListPersonalAccountsResponseClass(unittest.TestCase):
    """ListPersonalAccountsResponseClass unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testListPersonalAccountsResponseClass(self):
        """Test ListPersonalAccountsResponseClass"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ListPersonalAccountsResponseClass()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
